==> uoa-login-core-3.0.0-sources.jar: eu/dnetlib/authentication/services/UserInfoService.java <==
package eu.dnetlib.authentication.services;

import eu.dnetlib.authentication.configuration.Properties;
import eu.dnetlib.authentication.entities.TokenResponse;
import eu.dnetlib.authentication.entities.User;
import eu.dnetlib.authentication.exception.ResourceNotFoundException;
import jakarta.servlet.http.HttpServletRequest;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.*;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.oauth2.client.OAuth2AuthorizedClient;
import org.springframework.security.oauth2.client.authentication.OAuth2AuthenticationToken;
import org.springframework.security.oauth2.client.registration.ClientRegistration;
import org.springframework.security.oauth2.client.registration.ClientRegistrationRepository;
import org.springframework.security.oauth2.client.web.OAuth2AuthorizedClientRepository;
import org.springframework.security.oauth2.core.oidc.user.DefaultOidcUser;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.util.Objects;

@Service
public class UserInfoService {

    private static final Logger logger = LogManager.getLogger(UserInfoService.class);
    private final Properties properties;
    private final RestTemplate restTemplate;
    private final SecurityService service;
    private final OAuth2AuthorizedClientRepository repository;
    private final ClientRegistration client;

    @Autowired
    public UserInfoService(Properties properties, RestTemplate restTemplate, SecurityService service,
                           OAuth2AuthorizedClientRepository repository, ClientRegistrationRepository clientRegistrationRepository) {
        this.properties = properties;
        this.restTemplate = restTemplate;
        this.service = service;
        this.repository = repository;
        this.client = clientRegistrationRepository.findByRegistrationId(properties.getKeycloak().getName());
    }

    private OAuth2AuthorizedClient getAuthorizedClient(HttpServletRequest request) {
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        return this.repository.loadAuthorizedClient(properties.getKeycloak().getName(), authentication, request);
    }

    private String getAccessToken(OAuth2AuthorizedClient client) {
        if(client != null) {
            return client.getAccessToken().getTokenValue();
        }
        return null;
    }

    private String getRefreshToken(OAuth2AuthorizedClient client) {
        if(this.service.hasRefreshToken() && client != null) {
            return Objects.requireNonNull(client.getRefreshToken()).getTokenValue();
        }
        return null;
    }

    public User getUserInfo(HttpServletRequest request) throws ResourceNotFoundException {
        OAuth2AuthenticationToken authentication = this.service.getToken();
        if(authentication != null) {
            OAuth2AuthorizedClient client = this.getAuthorizedClient(request);
            return new User((DefaultOidcUser) authentication.getPrincipal(), authentication.getAuthorities(), this.getAccessToken(client), this.getRefreshToken(client));
        }
        throw new ResourceNotFoundException("No Session has been found");
    }

    public TokenResponse getAccessToken(String refreshToken) {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
        HttpEntity<MultiValueMap<String, String>> entity = new HttpEntity<>(getTokenRequest(refreshToken), headers);
        return restTemplate.postForObject(this.client.getProviderDetails().getTokenUri(), entity, TokenResponse.class);
    }

    public MultiValueMap<String, String> getTokenRequest(String refreshToken) {
        MultiValueMap<String, String> map = new LinkedMultiValueMap<>();
        map.add("client_id", this.client.getClientId());
        map.add("client_secret", this.client.getClientSecret());
        map.add("grant_type", "refresh_token");
        map.add("refresh_token", refreshToken);
        map.add("scope", "openid");
        return map;
    }

    public void revoke(HttpServletRequest request) {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
        HttpEntity<MultiValueMap<String, String>> entity = new HttpEntity<>(revokeTokenRequest(this.getRefreshToken(this.getAuthorizedClient(request))), headers);
        try {
            restTemplate.exchange(this.client.getProviderDetails().getConfigurationMetadata().get("revocation_endpoint").toString(), HttpMethod.POST, entity, String.class);
        } catch (Exception e) {
            logger.error("Couldn't revoke refresh Tokens");
        }
    }

    public MultiValueMap<String, String> revokeTokenRequest(String refreshToken) {
        MultiValueMap<String, String> map = new LinkedMultiValueMap<>();
        map.add("client_id", this.client.getClientId());
        map.add("client_secret", this.client.getClientSecret());
        map.add("token", refreshToken);
        return map;
    }

    public ClientRegistration getClient() {
        return this.client;
    }
}

==> uoa-login-core-3.0.1-sources.jar: eu/dnetlib/authentication/services/UserInfoService.java <==
package eu.dnetlib.authentication.services;

import eu.dnetlib.authentication.configuration.Properties;
import eu.dnetlib.authentication.entities.TokenResponse;
import eu.dnetlib.authentication.entities.User;
import eu.dnetlib.uoaauthorizationlibrary.authorization.exceptions.http.NotFoundException;
import jakarta.servlet.http.HttpServletRequest;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.oauth2.client.OAuth2AuthorizedClient;
import org.springframework.security.oauth2.client.authentication.OAuth2AuthenticationToken;
import org.springframework.security.oauth2.client.registration.ClientRegistration;
import org.springframework.security.oauth2.client.registration.ClientRegistrationRepository;
import org.springframework.security.oauth2.client.web.OAuth2AuthorizedClientRepository;
import org.springframework.security.oauth2.core.oidc.user.DefaultOidcUser;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.util.Objects;

@Service
public class UserInfoService {

    private static final Logger logger = LogManager.getLogger(UserInfoService.class);
    private final String clientName;
    private final RestTemplate restTemplate;
    private final SecurityService service;
    private final OAuth2AuthorizedClientRepository repository;
    private final ClientRegistration client;

    @Autowired
    public UserInfoService(Properties properties, RestTemplate restTemplate, SecurityService service,
                           OAuth2AuthorizedClientRepository repository, ClientRegistrationRepository clientRegistrationRepository) {
        this.clientName = properties.getKeycloak().getName();
        this.restTemplate = restTemplate;
        this.service = service;
        this.repository = repository;
        this.client = clientRegistrationRepository.findByRegistrationId(properties.getKeycloak().getName());
    }

    private OAuth2AuthorizedClient getAuthorizedClient(HttpServletRequest request) {
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        return this.repository.loadAuthorizedClient(clientName, authentication, request);
    }

    private String getAccessToken(OAuth2AuthorizedClient client) {
        if(client != null) {
            return client.getAccessToken().getTokenValue();
        }
        return null;
    }

    private String getRefreshToken(OAuth2AuthorizedClient client) {
        if(this.service.hasRefreshToken() && client != null) {
            return Objects.requireNonNull(client.getRefreshToken()).getTokenValue();
        }
        return null;
    }

    public User getUserInfo(HttpServletRequest request) throws NotFoundException {
        OAuth2AuthenticationToken authentication = this.service.getToken();
        if(authentication != null) {
            OAuth2AuthorizedClient client = this.getAuthorizedClient(request);
            return new User((DefaultOidcUser) authentication.getPrincipal(), authentication.getAuthorities(), this.getAccessToken(client), this.getRefreshToken(client));
        }
        throw new NotFoundException("No Session has been found");
    }

    public TokenResponse getAccessToken(String refreshToken) {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
        HttpEntity<MultiValueMap<String, String>> entity = new HttpEntity<>(getTokenRequest(refreshToken), headers);
        return restTemplate.postForObject(this.client.getProviderDetails().getTokenUri(), entity, TokenResponse.class);
    }

    public MultiValueMap<String, String> getTokenRequest(String refreshToken) {
        MultiValueMap<String, String> map = new LinkedMultiValueMap<>();
        map.add("client_id", this.client.getClientId());
        map.add("client_secret", this.client.getClientSecret());
        map.add("grant_type", "refresh_token");
        map.add("refresh_token", refreshToken);
        map.add("scope", "openid");
        return map;
    }

    public void revoke(HttpServletRequest request) {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
        HttpEntity<MultiValueMap<String, String>> entity = new HttpEntity<>(revokeTokenRequest(this.getRefreshToken(this.getAuthorizedClient(request))), headers);
        try {
            restTemplate.exchange(this.client.getProviderDetails().getConfigurationMetadata().get("revocation_endpoint").toString(), HttpMethod.POST, entity, String.class);
        } catch (Exception e) {
            logger.error("Couldn't revoke refresh Tokens");
        }
    }

    public MultiValueMap<String, String> revokeTokenRequest(String refreshToken) {
        MultiValueMap<String, String> map = new LinkedMultiValueMap<>();
        map.add("client_id", this.client.getClientId());
        map.add("client_secret", this.client.getClientSecret());
        map.add("token", refreshToken);
        return map;
    }

    public ClientRegistration getClient() {
        return this.client;
    }
}
